from setuptools import setup

setup(name='lujing_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['lujing_distributions'],
      author = 'Lujing Yang',
      author_email = 'lujing@me.com',
      zip_safe=False)
